Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMichael Valenta2007-03-02 15:06:22 +0000
committerMichael Valenta2007-03-02 15:06:22 +0000
commitc55d314f313114351f9dbe8477865f46ad4a23ae (patch)
tree44eccc554c5f8344a25221361bf4119446f0f645 /bundles/org.eclipse.core.net
parent50a23af4eecaaf639e95ca12c118cf44f03c246c (diff)
downloadeclipse.platform.team-c55d314f313114351f9dbe8477865f46ad4a23ae.tar.gz
eclipse.platform.team-c55d314f313114351f9dbe8477865f46ad4a23ae.tar.xz
eclipse.platform.team-c55d314f313114351f9dbe8477865f46ad4a23ae.zip
Changed instance of manager to service
Diffstat (limited to 'bundles/org.eclipse.core.net')
-rw-r--r--bundles/org.eclipse.core.net/src/org/eclipse/core/internal/net/ProxyManager.java2
-rw-r--r--bundles/org.eclipse.core.net/src/org/eclipse/core/net/proxy/IProxyChangeEvent.java4
-rw-r--r--bundles/org.eclipse.core.net/src/org/eclipse/core/net/proxy/IProxyService.java6
3 files changed, 6 insertions, 6 deletions
diff --git a/bundles/org.eclipse.core.net/src/org/eclipse/core/internal/net/ProxyManager.java b/bundles/org.eclipse.core.net/src/org/eclipse/core/internal/net/ProxyManager.java
index 86f7a5dd0..15eec3214 100644
--- a/bundles/org.eclipse.core.net/src/org/eclipse/core/internal/net/ProxyManager.java
+++ b/bundles/org.eclipse.core.net/src/org/eclipse/core/internal/net/ProxyManager.java
@@ -130,7 +130,7 @@ public class ProxyManager implements IProxyService {
String[] hosts = getNonProxiedHosts();
IProxyData[] changedProxies = internalSetProxyData(proxyDatas);
if (changedProxies.length > 0) {
- IProxyChangeEvent event = new ProxyChangeEvent(IProxyChangeEvent.PROXY_MANAGER_ENABLEMENT_CHANGE, hosts, hosts, oldData, changedProxies);
+ IProxyChangeEvent event = new ProxyChangeEvent(IProxyChangeEvent.PROXY_SERVICE_ENABLEMENT_CHANGE, hosts, hosts, oldData, changedProxies);
fireChange(event);
}
}
diff --git a/bundles/org.eclipse.core.net/src/org/eclipse/core/net/proxy/IProxyService.java b/bundles/org.eclipse.core.net/src/org/eclipse/core/net/proxy/IProxyService.java
index 18145863c..7c2cc8db5 100644
--- a/bundles/org.eclipse.core.net/src/org/eclipse/core/net/proxy/IProxyService.java
+++ b/bundles/org.eclipse.core.net/src/org/eclipse/core/net/proxy/IProxyService.java
@@ -27,7 +27,7 @@ public interface IProxyService {
* still kept so clients should check the enablement using {@link #isProxiesEnabled()}
* before calling the {@link #getProxyData()} or {@link #getProxyData(String)} method.
* However, the {@link #getProxyDataForHost(String)} and {@link #getProxyDataForHost(String, String)}
- * method will check the enablement and only return data if the manager is enabled.
+ * method will check the enablement and only return data if the service is enabled.
* @param enabled whether proxy support should be enabled
*/
void setProxiesEnabled(boolean enabled);
@@ -62,7 +62,7 @@ public interface IProxyService {
/**
* Return the proxy data for the proxy of the given type
* or <code>null</code> if the proxy type is not known by this
- * manager.
+ * service.
* @param type the proxy type
* @return the proxy data for the proxy of the given type
* or <code>null</code>
@@ -75,7 +75,7 @@ public interface IProxyService {
/**
* Return the proxy data for the proxy of the given type
* or <code>null</code> if the proxy type is not known by this
- * manager, the proxy data is empty for that type or the
+ * service, the proxy data is empty for that type or the
* host is in the non-proxied host list.
* @param host the host for which a connection is desired
* @param type the proxy type

Back to the top
diff --git a/bundles/org.eclipse.core.net/src/org/eclipse/core/net/proxy/IProxyChangeEvent.java b/bundles/org.eclipse.core.net/src/org/eclipse/core/net/proxy/IProxyChangeEvent.java
index caed9d712..e8b7ff4a4 100644
--- a/bundles/org.eclipse.core.net/src/org/eclipse/core/net/proxy/IProxyChangeEvent.java
+++ b/bundles/org.eclipse.core.net/src/org/eclipse/core/net/proxy/IProxyChangeEvent.java
@@ -35,12 +35,12 @@ public interface IProxyChangeEvent {
/**
* Type constant that indicates that the enablement of the proxy
* manager has changed. Client should consult the manager to determine
* the current enablement
* @see #getChangeType()
* @see IProxyService#isProxiesEnabled()
*/
- public static final int PROXY_MANAGER_ENABLEMENT_CHANGE = 3;
+ public static final int PROXY_SERVICE_ENABLEMENT_CHANGE = 3;
/**
* Return the type of change this event represents. Clients
@@ -35,12 +35,12 @@ public interface IProxyChangeEvent {
/**
* Type constant that indicates that the enablement of the proxy
- * manager has changed. Client should consult the manager to determine
+ * service has changed. Client should consult the service to determine
* the current enablement
* @see #getChangeType()